src.MEDS\_tabular\_automl.scripts.tabularize\_time\_series
==========================================================

.. automodule:: src.MEDS_tabular_automl.scripts.tabularize_time_series







   .. rubric:: Functions

   .. autosummary::

      main
